@@ -184,23 +184,6 @@ L.Storage.Map.include({
         if (this.options.allowEdit) {
             L.Storage.fire('ui:tooltip:init', {map: this});
             this.editTools = new L.S.Editable(this);
-            // Layer for items added by users
-            this.on('editable:drawing:cancel', function (e) {
-                if (e.layer._latlngs && e.layer._latlngs.length < e.layer.editor.MIN_VERTEX) e.layer.del();
-                if (e.layer instanceof L.S.Marker) e.layer.del();
-            });
-            this.on('editable:drawing:commit', function (e) {
-                e.layer.isDirty = true;
-                if (this.editedFeature !== e.layer) e.layer.edit(e);
-            });
-            this.on('editable:editing', function (e) {
-                e.layer.isDirty = true;
-            });
-            this.on('editable:vertex:ctrlclick', function (e) {
-                var index = e.vertex.getIndex();
-                if (index === 0) e.layer.editor.continueBackward();
-                else if (index === e.vertex.getLastIndex()) e.layer.editor.continueForward();
-            });
             L.Storage.on('ui:end ui:start', function () {
                 this.editedFeature = null;
             }, this);
